{ pkgs
, lib
, inputs
, config
, ...
}: {
  imports = [
    ./../../home/base.nix
  ];

  home.packages = with pkgs; [
    alacritty
    bat
    bottom
    cocoapods
    emacs
    unstable.eza
    gnutar
    iterm2
    ncdu
    neofetch
    nix-index
    nodejs
    unstable.ripes
    spotify
    tldr
    zellij
  ];

  programs.zsh = {
    shellAliases."rebuild" = "darwin-rebuild switch --flake /Users/felixalb/nix";
    prezto.pmodules = [ "ssh" ];
  };

  # Copy Applications to ~/Applications to allow them to be launched from Spotlight
  disabledModules = [ "targets/darwin/linkapps.nix" ];
  home.activation = lib.mkIf pkgs.stdenv.isDarwin {
    copyApplications =
      let
        apps = pkgs.buildEnv {
          name = "home-manager-applications";
          paths = config.home.packages;
          pathsToLink = "/Applications";
        };
      in
      lib.hm.dag.entryAfter [ "writeBoundary" ] ''
        baseDir="$HOME/Applications/Home Manager Apps"
        if [ -d "$baseDir" ]; then
          rm -rf "$baseDir"
        fi
        mkdir -p "$baseDir"
        for appFile in ${apps}/Applications/*; do
          target="$baseDir/$(basename "$appFile")"
          $DRY_RUN_CMD cp ''${VERBOSE_ARG:+-v} -fHRL "$appFile" "$baseDir"
          $DRY_RUN_CMD chmod ''${VERBOSE_ARG:+-v} -R +w "$target"
        done
      '';
  };

  home.stateVersion = "23.05";
}
